@@ -173,6 +173,7 @@ gsm_tree_view_load_state (GsmTreeView *tree_view)
 
             key = g_strdup_printf ("col-%d-width", sort_id);
             gtk_tree_view_column_set_fixed_width (col, g_settings_get_int (priv->settings, key));
+            gtk_tree_view_column_set_min_width (col, 30);
             g_free (key);
 
             key = g_strdup_printf ("col-%d-visible", sort_id);
@@ -230,7 +231,7 @@ save_column_state (gpointer data)
     key = g_strdup_printf ("col-%d-visible", column_id);
     g_settings_set_boolean (settings, key, visible);
     g_free (key);
-
+    timeout_id = 0;
     return FALSE;
 }
 
@@ -241,10 +242,10 @@ cb_update_column_state (GObject *object, GParamSpec *pspec, gpointer data)
 
     current_column = column;
 
-    if (timeout_id)
+    if (timeout_id > 0)
         g_source_remove (timeout_id);
 
-    timeout_id = g_timeout_add (250, save_column_state, data);
+    timeout_id = g_timeout_add_seconds (1, save_column_state, data);
 }
 
 void
